@@ -252,9 +252,15 @@ def http_clone_url(context, mapping):
         easier for users to clone repositories.
     """
 
-    ui = context.resource(mapping, b'ui')
+    urlbase = context.symbol(mapping, b'urlbase')
+    if urlbase.endswith(b'/'):
+        urlbase = urlbase[:-1]
 
-    return ui.config(b'web', b'http_clone_url', b'')
+    path = context.symbol(mapping, b'url')
+    if path.startswith(b'/'):
+        path = path[1:]
+
+    return urlbase + b'/' + path
 
 
 def http_base_url(context, mapping):
@@ -346,8 +352,7 @@ def repo_custom_templater(orig, self, req):
 
     templatekeyword = registrar.templatekeyword(templater._proc._defaults)
 
-    templatekeyword(b'http_clone_url', requires={b'ui'})(http_clone_url)
-    templatekeyword(b'http_base_url', requires={b'ui'})(http_base_url)
+    templatekeyword(b'http_clone_url', requires=())(http_clone_url)
     templatekeyword(b'readme', requires={b'ctx', b'repo'})(readme)
     templatekeyword(b'ssh_clone_url', requires={b'ui', b'repo'})(ssh_clone_url)
 
